==> v1.6.0.tar.gz: zyos_go_order_relate_rule/db/db_user_small_public_platoon_relation.go <==
package db

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db/model"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils/logx"
	"errors"
	"fmt"
	"reflect"
	"xorm.io/xorm"
)

// BatchSelectUserSmallPublicPlatoonRelations 批量查询数据 TODO::和下面的方法重复了，建议采用下面的 `UserSmallPublicPlatoonRelationFindByParams` 方法
func BatchSelectUserSmallPublicPlatoonRelations(Db *xorm.Engine, params map[string]interface{}) (*[]model.UserSmallPublicPlatoonRelation, error) {
	var UserSmallPublicPlatoonRelationData []model.UserSmallPublicPlatoonRelation
	if err := Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).
		Find(&UserSmallPublicPlatoonRelationData); err != nil {
		return nil, zhios_order_relate_logx.Warn(err)
	}
	return &UserSmallPublicPlatoonRelationData, nil
}

// UserSmallPublicPlatoonRelationInsert 插入单条数据
func UserSmallPublicPlatoonRelationInsert(Db *xorm.Engine, UserSmallPublicPlatoonRelation *model.UserSmallPublicPlatoonRelation) (int, error) {
	_, err := Db.InsertOne(UserSmallPublicPlatoonRelation)
	if err != nil {
		return 0, err
	}
	return UserSmallPublicPlatoonRelation.Id, nil
}

// BatchAddUserSmallPublicPlatoonRelations 批量新增数据
func BatchAddUserSmallPublicPlatoonRelations(Db *xorm.Engine, UserSmallPublicPlatoonRelationData []*model.UserSmallPublicPlatoonRelation) (int64, error) {
	affected, err := Db.Insert(UserSmallPublicPlatoonRelationData)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func GetUserSmallPublicPlatoonRelationCount(Db *xorm.Engine) int {
	var UserSmallPublicPlatoonRelation model.UserSmallPublicPlatoonRelation
	session := Db.Where("")
	count, err := session.Count(&UserSmallPublicPlatoonRelation)
	if err != nil {
		return 0
	}
	return int(count)
}

// UserSmallPublicPlatoonRelationDelete 删除记录
func UserSmallPublicPlatoonRelationDelete(Db *xorm.Engine, id interface{}) (int64, error) {
	if reflect.TypeOf(id).Kind() == reflect.Slice {
		return Db.In("id", id).Delete(model.UserSmallPublicPlatoonRelation{})
	} else {
		return Db.Where("id = ?", id).Delete(model.UserSmallPublicPlatoonRelation{})
	}
}

// UserSmallPublicPlatoonRelationUpdate 更新记录
func UserSmallPublicPlatoonRelationUpdate(session *xorm.Session, id interface{}, UserSmallPublicPlatoonRelation *model.UserSmallPublicPlatoonRelation, forceColums ...string) (int64, error) {
	var (
		affected int64
		err      error
	)
	if forceColums != nil {
		affected, err = session.Where("id=?", id).Cols(forceColums...).Update(UserSmallPublicPlatoonRelation)
	} else {
		affected, err = session.Where("id=?", id).Update(UserSmallPublicPlatoonRelation)
	}
	if err != nil {
		return 0, err
	}
	return affected, nil
}

// UserSmallPublicPlatoonRelationGetOneByParams 通过传入的参数查询数据(单条)
func UserSmallPublicPlatoonRelationGetOneByParams(Db *xorm.Engine, params map[string]interface{}) (*model.UserSmallPublicPlatoonRelation, error) {
	var m model.UserSmallPublicPlatoonRelation
	var query = fmt.Sprintf("%s =?", params["key"])
	if has, err := Db.Where(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func UserSmallPublicPlatoonRelationGetOneByPid(Db *xorm.Engine, pid string, params map[string]interface{}) (*model.UserSmallPublicPlatoonRelation, error) {
	var m model.UserSmallPublicPlatoonRelation
	var query = fmt.Sprintf("%s =?", params["key"])
	if has, err := Db.Where("pid = ?", pid).And(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func UserSmallPublicPlatoonRelationFindByPidLike(Db *xorm.Engine, pid string) ([]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if err := Db.Where("pid like ?", "%"+pid+"%").OrderBy("position Desc").
		Find(m); err != nil {
		return nil, zhios_order_relate_logx.Warn(err)
	}
	return m, nil
}

// UserSmallPublicPlatoonRelationFindByParams 通过传入的参数查询数据(多条)
func UserSmallPublicPlatoonRelationFindByParams(Db *xorm.Engine, params map[string]interface{}) (*[]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if params["value"] == nil {
		return nil, errors.New("参数有误")
	}
	if params["key"] == nil {
		//查询全部数据
		err := Db.Find(&m)
		if err != nil {
			return nil, zhios_order_relate_logx.Error(err)
		}
		return &m, nil
	} else {
		if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
			//指定In查询
			if err := Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).Find(&m); err != nil {
				return nil, zhios_order_relate_logx.Warn(err)
			}
			return &m, nil
		} else {
			var query = fmt.Sprintf("%s =?", params["key"])
			err := Db.Where(query, params["value"]).Find(&m)
			if err != nil {
				return nil, zhios_order_relate_logx.Error(err)
			}
			return &m, nil
		}

	}
}

func UserSmallPublicPlatoonRelationFindByPosition(Db *xorm.Engine, params map[string]interface{}) ([]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if params["value"] == nil {
		return nil, errors.New("参数有误")
	}
	var query = fmt.Sprintf("%s >?", params["key"])
	err := Db.Where(query, params["value"]).Find(&m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return m, nil
}

func UserSmallPublicPlatoonRelationFindByParamsByPage(Db *xorm.Engine, params map[string]interface{}, page, pageSize int) (*[]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if params["value"] == nil {
		return nil, errors.New("参数有误")
	}
	if page == 0 && pageSize == 0 {
		page = 1
		pageSize = 10
	}

	if params["key"] == nil {
		//查询全部数据
		err := Db.Limit(pageSize, (page-1)*pageSize).Find(&m)
		if err != nil {
			return nil, zhios_order_relate_logx.Error(err)
		}
		return &m, nil
	} else {
		if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
			//指定In查询
			if err := Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).Limit(pageSize, (page-1)*pageSize).Find(&m); err != nil {
				return nil, zhios_order_relate_logx.Warn(err)
			}
			return &m, nil
		} else {
			var query = fmt.Sprintf("%s =?", params["key"])
			err := Db.Where(query, params["value"]).Limit(pageSize, (page-1)*pageSize).Find(&m)
			if err != nil {
				return nil, zhios_order_relate_logx.Error(err)
			}
			return &m, nil
		}

	}
}

==> v1.6.1.tar.gz: zyos_go_order_relate_rule/db/db_user_small_public_platoon_relation.go <==
package db

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db/model"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils/logx"
	"errors"
	"fmt"
	"reflect"
	"xorm.io/xorm"
)

// BatchSelectUserSmallPublicPlatoonRelations 批量查询数据 TODO::和下面的方法重复了，建议采用下面的 `UserSmallPublicPlatoonRelationFindByParams` 方法
func BatchSelectUserSmallPublicPlatoonRelations(Db *xorm.Engine, params map[string]interface{}) (*[]model.UserSmallPublicPlatoonRelation, error) {
	var UserSmallPublicPlatoonRelationData []model.UserSmallPublicPlatoonRelation
	if err := Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).
		Find(&UserSmallPublicPlatoonRelationData); err != nil {
		return nil, zhios_order_relate_logx.Warn(err)
	}
	return &UserSmallPublicPlatoonRelationData, nil
}

// UserSmallPublicPlatoonRelationInsert 插入单条数据
func UserSmallPublicPlatoonRelationInsert(Db *xorm.Engine, UserSmallPublicPlatoonRelation *model.UserSmallPublicPlatoonRelation) (int, error) {
	_, err := Db.InsertOne(UserSmallPublicPlatoonRelation)
	if err != nil {
		return 0, err
	}
	return UserSmallPublicPlatoonRelation.Id, nil
}

// BatchAddUserSmallPublicPlatoonRelations 批量新增数据
func BatchAddUserSmallPublicPlatoonRelations(Db *xorm.Engine, UserSmallPublicPlatoonRelationData []*model.UserSmallPublicPlatoonRelation) (int64, error) {
	affected, err := Db.Insert(UserSmallPublicPlatoonRelationData)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func GetUserSmallPublicPlatoonRelationCount(Db *xorm.Engine) int {
	var UserSmallPublicPlatoonRelation model.UserSmallPublicPlatoonRelation
	session := Db.Where("")
	count, err := session.Count(&UserSmallPublicPlatoonRelation)
	if err != nil {
		return 0
	}
	return int(count)
}

// UserSmallPublicPlatoonRelationDelete 删除记录
func UserSmallPublicPlatoonRelationDelete(Db *xorm.Engine, id interface{}) (int64, error) {
	if reflect.TypeOf(id).Kind() == reflect.Slice {
		return Db.In("id", id).Delete(model.UserSmallPublicPlatoonRelation{})
	} else {
		return Db.Where("id = ?", id).Delete(model.UserSmallPublicPlatoonRelation{})
	}
}

// UserSmallPublicPlatoonRelationUpdate 更新记录
func UserSmallPublicPlatoonRelationUpdate(session *xorm.Session, id interface{}, UserSmallPublicPlatoonRelation *model.UserSmallPublicPlatoonRelation, forceColums ...string) (int64, error) {
	var (
		affected int64
		err      error
	)
	if forceColums != nil {
		affected, err = session.Where("id=?", id).Cols(forceColums...).Update(UserSmallPublicPlatoonRelation)
	} else {
		affected, err = session.Where("id=?", id).Update(UserSmallPublicPlatoonRelation)
	}
	if err != nil {
		return 0, err
	}
	return affected, nil
}

// UserSmallPublicPlatoonRelationGetOneByParams 通过传入的参数查询数据(单条)
func UserSmallPublicPlatoonRelationGetOneByParams(Db *xorm.Engine, params map[string]interface{}) (*model.UserSmallPublicPlatoonRelation, error) {
	var m model.UserSmallPublicPlatoonRelation
	var query = fmt.Sprintf("%s =?", params["key"])
	if has, err := Db.Where(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func UserSmallPublicPlatoonRelationFindByEmptyPosition(Db *xorm.Engine) (*model.UserSmallPublicPlatoonRelation, error) {
	var m model.UserSmallPublicPlatoonRelation
	if has, err := Db.Where("uid = -1").Or("uid = -2").Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func UserSmallPublicPlatoonRelationGetOneByPid(Db *xorm.Engine, pid string, params map[string]interface{}) (*model.UserSmallPublicPlatoonRelation, error) {
	var m model.UserSmallPublicPlatoonRelation
	var query = fmt.Sprintf("%s =?", params["key"])
	if has, err := Db.Where("pid = ?", pid).And(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func UserSmallPublicPlatoonRelationFindByPidLike(Db *xorm.Engine, pid string) ([]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if err := Db.Where("father_uid like ?", "%"+pid+"%").OrderBy("id Desc").
		Find(&m); err != nil {
		return nil, zhios_order_relate_logx.Warn(err)
	}
	return m, nil
}

// UserSmallPublicPlatoonRelationFindByParams 通过传入的参数查询数据(多条)
func UserSmallPublicPlatoonRelationFindByParams(Db *xorm.Engine, params map[string]interface{}) (*[]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if params["value"] == nil {
		return nil, errors.New("参数有误")
	}
	if params["key"] == nil {
		//查询全部数据
		err := Db.Find(&m)
		if err != nil {
			return nil, zhios_order_relate_logx.Error(err)
		}
		return &m, nil
	} else {
		if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
			//指定In查询
			if err := Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).Find(&m); err != nil {
				return nil, zhios_order_relate_logx.Warn(err)
			}
			return &m, nil
		} else {
			var query = fmt.Sprintf("%s =?", params["key"])
			err := Db.Where(query, params["value"]).Find(&m)
			if err != nil {
				return nil, zhios_order_relate_logx.Error(err)
			}
			return &m, nil
		}

	}
}

func UserSmallPublicPlatoonRelationFindRecommends(Db *xorm.Engine) ([]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	var query = fmt.Sprintf("recommend_uid > 0")
	err := Db.Where(query).Find(&m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return m, nil
}

func UserSmallPublicPlatoonRelationFindByParamsByPage(Db *xorm.Engine, params map[string]interface{}, page, pageSize int) (*[]model.UserSmallPublicPlatoonRelation, error) {
	var m []model.UserSmallPublicPlatoonRelation
	if params["value"] == nil {
		return nil, errors.New("参数有误")
	}
	if page == 0 && pageSize == 0 {
		page = 1
		pageSize = 10
	}

	if params["key"] == nil {
		//查询全部数据
		err := Db.Limit(pageSize, (page-1)*pageSize).Find(&m)
		if err != nil {
			return nil, zhios_order_relate_logx.Error(err)
		}
		return &m, nil
	} else {
		if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
			//指定In查询
			if err := Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).Limit(pageSize, (page-1)*pageSize).Find(&m); err != nil {
				return nil, zhios_order_relate_logx.Warn(err)
			}
			return &m, nil
		} else {
			var query = fmt.Sprintf("%s =?", params["key"])
			err := Db.Where(query, params["value"]).Limit(pageSize, (page-1)*pageSize).Find(&m)
			if err != nil {
				return nil, zhios_order_relate_logx.Error(err)
			}
			return &m, nil
		}

	}
}
